==> accessibility-3.3.1-sources.jar: com/nanorep/accessibility/voice/engines/DroidSpeechProvider.kt <==
package com.nanorep.accessibility.voice.engines

import android.content.Context

class DroidSpeechProvider(val context: Context) /*: SpeechRecognitionProvider, OnDSListener*/ {

    /*private var recognizer: DroidSpeech = DroidSpeech(context, null)
    private var speechListener: SpeechedTextListener? = null
    private var isEnabled: Boolean = false

    override fun registerListener(speechedTextListener: SpeechedTextListener) {
        speechListener = speechedTextListener
    }

    init {
        recognizer.continuousSpeechRecognition = false
        recognizer.setOnDroidSpeechListener(this);
        recognizer.setOfflineSpeechRecognition(true)
        recognizer.setShowRecognitionProgressView(true)
    }

    override fun enable(enable: Boolean) {
        isEnabled = enable
    }

    override fun start(languge: Locale) {
        speechListener?.onStart()
        recognizer.setPreferredLanguage(languge.toString())
        speechListener?.onPrepared()
    }

    override fun cancel() {
        recognizer.closeDroidSpeechOperations()
    }

    override fun release() {
        recognizer.setOnDroidSpeechListener(null)
        speechListener = null
    }

    override fun onDroidSpeechRmsChanged(rmsChangedValue: Float) {

    }

    override fun onDroidSpeechSupportedLanguages(currentSpeechLanguage: String?, supportedSpeechLanguages: MutableList<String>?) {

    }

    override fun onDroidSpeechError(errorMsg: String?) {
        speechListener?.onError(ErrorInfo(-1, errorMsg ?: "something went wrong"))
    }

    override fun onDroidSpeechClosedByUser() {

    }

    override fun onDroidSpeechLiveResult(liveSpeechResult: String?) {

    }

    override fun onDroidSpeechFinalResult(finalSpeechResult: String?) {
        speechListener?.onResults(finalSpeechResult?:"")
    }
*/
}

==> accessibility-4.1.1.1.rc1-sources.jar: com/nanorep/accessibility/voice/engines/DroidSpeechProvider.kt <==
package com.nanorep.accessibility.voice.engines

import android.content.Context
import com.nanorep.accessibility.voice.RecognitionErrorCodes
import com.nanorep.accessibility.voice.SpeechRecognitionProvider
import com.nanorep.accessibility.voice.SpeechedTextListener
import com.nanorep.sdkcore.utils.NRError
import java.util.*

class DroidSpeechProvider(val context: Context) /*: SpeechRecognitionProvider, OnDSListener {

    private var recognizer: DroidSpeech = DroidSpeech(context, null)
    private var speechListener: SpeechedTextListener? = null
    private var isEnabled: Boolean = false

    override fun registerListener(speechedTextListener: SpeechedTextListener) {
        speechListener = speechedTextListener
    }

    init {
        recognizer.continuousSpeechRecognition = true
        recognizer.setOnDroidSpeechListener(this);
        recognizer.setOfflineSpeechRecognition(true)
        recognizer.setShowRecognitionProgressView(true)
    }

    override fun enable(enable: Boolean) {
        isEnabled = enable
    }

    override fun start(languge: Locale) {
        speechListener?.onStart()
        recognizer.setPreferredLanguage(languge.toString())
        speechListener?.onPrepared()
        recognizer.startDroidSpeechRecognition()
    }

    override fun cancel() {
        recognizer.closeDroidSpeechOperations()
    }

    override fun stop() {
        recognizer.closeDroidSpeechOperations()
    }

    override fun release() {
        recognizer.setOnDroidSpeechListener(null)
        speechListener = null
    }

    override var speechCompleteSilenceTimeout: Int? = 5000
    override var partialResultsEnabled: Boolean = true

    override fun onDroidSpeechRmsChanged(rmsChangedValue: Float) {

    }

    override fun onDroidSpeechSupportedLanguages(currentSpeechLanguage: String?, supportedSpeechLanguages: MutableList<String>?) {

    }

    override fun onDroidSpeechError(errorMsg: String?) {
        speechListener?.onError(NRError(RecognitionErrorCodes.ERROR_RECORDING, errorMsg ?: "something went wrong"))
    }

    override fun onDroidSpeechClosedByUser() {

    }

    override fun onDroidSpeechLiveResult(liveSpeechResult: String?) {
        speechListener?.onResults(liveSpeechResult?:"")

    }

    override fun onDroidSpeechFinalResult(finalSpeechResult: String?) {
        speechListener?.onResults(finalSpeechResult?:"")
    }
}*/
